// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

namespace ControllersFromServicesWebSite;

public class ValueService
{
    public int Value { get; } = 3;
}
